@@ -18,7 +18,7 @@ use vars qw(
   Curses::UI::Common
   );
 
-$VERSION = '1.1';
+$VERSION = '1.2';
 
 my $var_name_spaces = 20;
 
@@ -28,6 +28,18 @@ sub new {
 
     $this->set_binding(\&delete_item, KEY_DC) unless $this->{-readonly};
     $this->set_binding(\&show_item, KEY_ENTER);
+    $this->set_binding(
+        sub {
+            my $str = "";
+            foreach my $rh (sort { $a->{name} cmp $b->{name} } @{$this->{-named_list}}) {
+                $str .= $rh->{name} . "\t=>\t" . $rh->{long_value} . "\n";
+            }
+            DB::export_to_file(undef, "Variables", \$str);
+        },
+        KEY_F(6),
+        "\cS",
+        "\cL",
+    );
 
     $this;
 }
@@ -46,14 +58,13 @@ sub show_item {
     my $id   = $this->get_active_id;
     my $item = $this->{-named_list}->[$id];
 
-    Devel::PDB::Dialog::Message->run(-title => $item->{name}, -message => $item->{long_value}, %DB::def_style);
+    DB::dialog_message(-title => $item->{name}, -message => $item->{long_value});
 }
 
 sub named_list {
     my ($this, $list) = @_;
 
     $this->{-named_list} = $list if defined $list;
-
     $this->{-named_list};
 }
 
