@@ -87,14 +87,14 @@ sub toogle_break_cond {
 
     my $cond = $Curses::UI::rootobject->question(
         -question => $str . "\n$x",
-        %DB::def_style,
+        DB::window_style(),
         -title  => "Eval in breakpoint",
         -answer => $action,
     );
     return 0 if (!$cond || !length($cond));
-    my $str = $cond;
-    $str =~ s/ //g;
-    return 0 unless length($str);
+    my $text = $cond;
+    $text =~ s/ //g;
+    return 0 unless length($text);
     return "1\0" . $cond;
 }
 
